# Cats core

Cats core is a Python library for [cats project](https://finance.rescala.jp/?page_id=204).

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install foobar.

```bash
pip install catscore
```

## Usage

```python
tbd = "TBD
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://choosealicense.com/licenses/mit/)